#!/bin/sh
### BEGIN INIT INFO
# Provides:          helix-p4dctl
# Required-Start:    $local_fs $named $network $remote_fs $syslog $time
# Required-Stop:     $remote_fs
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Starts all Perforce services
# Description:       Perforce provides powerful distributed Version Management 
#		     (SCM) to developers and other content editors. This script 
#		     invokes p4dctl to start all configured Perforce services 
#		     on this host.
### END INIT INFO

# Author: Perforce Software (support@perforce.com)

# PATH should only include /usr/* if it runs after the mountnfs.sh script

PATH=/sbin:/usr/sbin:/bin:/usr/bin
DESC="Perforce Services"        # short description 
NAME=p4dctl            		# Program name 
PROG=/usr/bin/p4dctl 		# Introduce the program's location here
PROG_ARGS=""             	# Arguments to run the program with
CMD_ARGS=""             	# Arguments to pass to commands

# Exit if the package is not installed
[ -x $PROG ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#
do_start()
{
	$PROG $PROG_ARGS start $CMD_ARGS
}


#
# Function that stops the daemon/service
#
do_stop()
{
	$PROG $PROG_ARGS stop $CMD_ARGS || true
}

case "$1" in
  start)
    [ "$VERBOSE" != no ] && log_daemon_msg "Starting $DESC" "$NAME"
    do_start
    case "$?" in
		0) [ "$VERBOSE" != no ] && log_end_msg 0 
		   exit 0
		   ;;
		*) [ "$VERBOSE" != no ] && log_end_msg 1 
		   exit 1
		   ;;
	esac
  ;;
  stop)
	[ "$VERBOSE" != no ] && log_daemon_msg "Stopping $DESC" "$NAME"
	do_stop
	case "$?" in
		0) [ "$VERBOSE" != no ] && log_end_msg 0 
		   exit 0
		   ;;
		*) [ "$VERBOSE" != no ] && log_end_msg 1 
		   exit 1
		   ;;
	esac
	;;
  status)
       $PROG status $PROG_ARGS
       ;;
  restart|force-reload)
	#
	# If the "reload" option is implemented then remove the
	# 'force-reload' alias
	#
	log_daemon_msg "Restarting $DESC" "$NAME"
	do_stop
	case "$?" in
	  0)
		do_start
		case "$?" in
			0) log_end_msg 0 ;;
			*) log_end_msg 1 ;; # Failed to start
		esac
		;;
	  *)
	  	# Failed to stop
		log_end_msg 1
		;;
	esac
	;;
  *)
	SCRIPTNAME=$(basename "$0")
	echo "Usage: $SCRIPTNAME {start|stop|status|restart|force-reload}" >&2

	exit 3
	;;
esac
